@@ -1,4 +1,4 @@
-"krige.bayes.extnd" <- 
+".krige.bayes.extnd" <- 
   function(geodata, coords=geodata$coords, data=geodata$data,
            locations = "no", model, prior, output)
 {
@@ -24,10 +24,10 @@
   else{
     if(class(model) != "model.geoR"){
       if(!is.list(model))
-        stop("krige.bayes.extnd: the argument model only takes a list or an output of the function model.control")
+        stop(".krige.bayes.extnd: the argument model only takes a list or an output of the function model.control")
       else{
         model.names <- c("trend.d", "trend.l", "cov.model", "kappa", "aniso.pars", "lambda") 
-        model <- object.match.names(model,model.names)
+        model <- .object.match.names(model,model.names)
         if(is.null(model$trend.d)) model$trend.d <- "cte"  
         if(is.null(model$trend.l)) model$trend.l <- "cte"  
         if(is.null(model$cov.model)) model$cov.model <- "matern"  
@@ -44,7 +44,7 @@
     }
   }
   cov.model <- model$cov.model
-  cov.model.number <- cor.number(cov.model)
+  cov.model.number <- .cor.number(cov.model)
   kappa <- model$kappa
   ##
   ## reading prior input
@@ -54,12 +54,12 @@
   else{
     if(class(prior) != "prior.geoR"){
       if(!is.list(prior))
-        stop("krige.bayes.extnd: the argument prior only takes a list or an output of the function prior.control")
+        stop(".krige.bayes.extnd: the argument prior only takes a list or an output of the function prior.control")
       else{
         prior.names <- c("beta.prior", "beta", "beta.var.std", "sigmasq.prior",
                          "sigmasq", "df.sigmasq", "phi.prior", "phi", "phi.discrete",
                          "tausq.rel.prior", "tausq.rel", "tausq.rel.discrete") 
-        prior <- object.match.names(prior,prior.names)
+        prior <- .object.match.names(prior,prior.names)
         ## DO NOT CHANGE ORDER OF THE NEXT 3 LINES
         if(is.null(prior$beta)) prior$beta <-  NULL
         if(is.null(prior$beta.prior)) prior$beta.prior <-  c("flat", "normal", "fixed")
@@ -104,29 +104,29 @@
   if(prior$beta.prior == "fixed") beta.fixed <- beta
   if(prior$beta.prior == "normal"){
     beta.var.std <- prior$beta.var.std
-    inv.beta.var.std <- solve.geoR(beta.var.std)
-    betares <- list(iv = inv.beta.var.std, ivm = drop(solve.geoR(beta.var.std, beta)),
-                    mivm = drop(crossprod(beta, solve.geoR(beta.var.std, beta))))
+    inv.beta.var.std <- .solve.geoR(beta.var.std)
+    betares <- list(iv = inv.beta.var.std, ivm = drop(.solve.geoR(beta.var.std, beta)),
+                    mivm = drop(crossprod(beta, .solve.geoR(beta.var.std, beta))))
   }
   if(prior$sigmasq.prior == "fixed") sigmasq.fixed <- prior$sigmasq
   else S2.prior <- prior$sigmasq
   df.sigmasq <- prior$df.sigmasq
   ##
-  if(prior$phi.prior != "fixed") stop("krige.bayes.extnd: only phi fixed is allowed.")
+  if(prior$phi.prior != "fixed") stop(".krige.bayes.extnd: only phi fixed is allowed.")
   ##
   tausq.rel.fixed <- tausq.rel <- prior$tausq.rel
-  if(prior$tausq.rel.prior != "fixed") stop("krige.bayes.extnd: only tausq fixed is allowed.")
+  if(prior$tausq.rel.prior != "fixed") stop(".krige.bayes.extnd: only tausq fixed is allowed.")
   ##
   ## checking data configuration
   ##
   data <- as.matrix(data)
   n.datasets <- ncol(data)
   n <- nrow(data)
-  if(n.datasets == 1) stop("krige.bayes.extnd: this function is for multiple datasets. Use krige.bayes instead.")
+  if(n.datasets == 1) stop(".krige.bayes.extnd: this function is for multiple datasets. Use krige.bayes instead.")
   ##
   if(is.vector(coords)){
     coords <- cbind(coords, 0)
-    warning("krige.bayes.extnd: vector of coordinates: assuming one spatial dimension (transect)")
+    warning(".krige.bayes.extnd: vector of coordinates: assuming one spatial dimension (transect)")
   }
   coords <- as.matrix(coords)
   dists.env <- new.env()
@@ -134,7 +134,7 @@
   data.dist.range <- range(get("data.dist", envir=dists.env))
   data.dist.min <- data.dist.range[1]
   data.dist.max <- data.dist.range[2]
-  if(1e12*data.dist.min < 0.5) stop("krige.bayes.extnd: this function does not allow two data at same location")
+  if(1e12*data.dist.min < 0.5) stop(".krige.bayes.extnd: this function does not allow two data at same location")
   ##
   ## reading output options
   ##
@@ -143,11 +143,11 @@
   else{
     if(class(output) != "output.geoR"){
       if(!is.list(output))
-        stop("krige.bayes.extnd: the argument output only takes a list or an output of the function output.control")
+        stop(".krige.bayes.extnd: the argument output only takes a list or an output of the function output.control")
       else{
         output.names <- c("n.posterior","n.predictive","moments","n.back.moments","simulations.predictive",
                           "mean.var","quantile","threshold","signal","messages.screen")
-        output <- object.match.names(output,output.names)
+        output <- .object.match.names(output,output.names)
         if(is.null(output$n.posterior)) output$n.posterior <- 1000 
         if(is.null(output$n.predictive)) output$n.predictive <- NULL
         if(is.null(output$moments)) output$moments <- TRUE
@@ -180,59 +180,62 @@
     if(is.null(n.predictive)) n.predictive <- as.integer(0)
     simulations.predictive <- output$simulations.predictive
     if(is.null(simulations.predictive)) simulations.predictive <- FALSE
-    if(!is.null(output$signal) && output$signal) stop("krige.bayes.extnd: prediction of the signal is not implemented")
-    if(!is.null(output$probability.estimator)) stop("krige.bayes.extnd: probability.estimator not implemented\n")
-    if(!is.null(output$quantile.estimator)) stop("krige.bayes.extnd: quantile.estimator not implemented\n")
+    if(!is.null(output$signal) && output$signal) stop(".krige.bayes.extnd: prediction of the signal is not implemented")
+    if(!is.null(output$probability.estimator)) stop(".krige.bayes.extnd: probability.estimator not implemented\n")
+    if(!is.null(output$quantile.estimator)) stop(".krige.bayes.extnd: quantile.estimator not implemented\n")
     if(simulations.predictive && n.predictive == 0) n.predictive <- as.integer(1)
   }
   ##
   ## Box-Cox transformation
   ##
-  if(abs(model$lambda-1)>0.0001) stop("krige.bayes.extnd: Box-Cox transformation not allowed \n")    
+  if(abs(model$lambda-1)>0.0001) stop(".krige.bayes.extnd: Box-Cox transformation not allowed \n")    
   ##
   ## Building trend (covariates/design) matrices:   
   ##
   dimnames(coords) <- list(NULL, NULL)
-  if(nrow(coords) != n) stop("krige.bayes.extnd: number of data is different of number of data locations (coordinates)")
+  if(nrow(coords) != n) stop(".krige.bayes.extnd: number of data is different of number of data locations (coordinates)")
   trend.data <- unclass(trend.spatial(trend=model$trend.d, geodata = geodata))
   beta.size <- ncol(trend.data)
   if(nrow(trend.data) != n) stop("length of trend is different from the length of the data")
   if((prior$beta.prior == "normal") && (beta.size != length(beta)) )
-    stop("krige.bayes.extnd: size of beta incompatible with the trend model (covariates)")
+    stop(".krige.bayes.extnd: size of beta incompatible with the trend model (covariates)")
   ##
   if(do.prediction) {
-    locations <- check.locations(locations)
+    locations <- .check.locations(locations)
     ##
     ## Checking trend specification
     ##
     if(inherits(model$trend.d, "formula") | inherits(model$trend.l, "formula")){
       if((inherits(model$trend.d, "formula") == FALSE) | (inherits(model$trend.l, "formula") == FALSE))
-        stop("krige.bayes.extnd: model$trend.d and model$trend.l must have similar specification\n")
+        stop(".krige.bayes.extnd: model$trend.d and model$trend.l must have similar specification\n")
     }
     else{
       if((class(model$trend.d) == "trend.spatial") & (class(model$trend.l) == "trend.spatial")){
         if(ncol(model$trend.d) != ncol(model$trend.l))
-          stop("krige.bayes.extnd: trend.d and trend.l do not have the same number of columns")
+          stop(".krige.bayes.extnd: trend.d and trend.l do not have the same number of columns")
       }
       else
         if(model$trend.d != model$trend.l)
-          stop("krige.bayes.extnd: especification of model$trend.l and model$trend.d must be similar")
+          stop(".krige.bayes.extnd: especification of model$trend.l and model$trend.d must be similar")
     }
     ##
     if(messages.screen){
       cat(switch(model$trend.d,
-                 "cte" = "krige.bayes.extnd: model with mean being constant",
-                 "1st" = "krige.bayes.extnd: model with mean given by a 1st order polynomial on the coordinates",
-                 "2nd" = "krige.bayes.extnd: model with mean given by a 2nd order polynomial on the coordinates",
-                 "krige.bayes.extnd: model with mean defined by covariates provided by the user"))
+                 "cte" = ".krige.bayes.extnd: model with mean being constant",
+                 "1st" = ".krige.bayes.extnd: model with mean given by a 1st order polynomial on the coordinates",
+                 "2nd" = ".krige.bayes.extnd: model with mean given by a 2nd order polynomial on the coordinates",
+                 ".krige.bayes.extnd: model with mean defined by covariates provided by the user"))
       cat("\n")
     }
     ##
     dimnames(locations) <- list(NULL, NULL)
-    assign("trend.loc", unclass(trend.spatial(trend=model$trend.l, geodata = list(coords = locations))), envir=pred.env)
+    if(class(model$trend.l) == "trend.spatial")
+      assign("trend.loc", unclass(model$trend.l), envir=pred.env)
+    else
+      assign("trend.loc", unclass(trend.spatial(trend=model$trend.l, geodata = list(coords = locations))), envir=pred.env)
     ni <- nrow(get("trend.loc", envir=pred.env))
     if(nrow(locations) != ni)
-      stop("krige.bayes.extnd: number of points to be estimated is different of the number of trend locations")
+      stop(".krige.bayes.extnd: number of points to be estimated is different of the number of trend locations")
   }
   ##
   ## Anisotropy correction
@@ -240,7 +243,7 @@
   ##
   if(!is.null(model$aniso.pars)) {
     if((abs(model$aniso.pars[1]) > 0.001) & (abs(model$aniso.pars[2] - 1) > 0.001)){
-      if(messages.screen) cat("krige.bayes.extnd: anisotropy parameters provided and assumed to be constants\n")
+      if(messages.screen) cat(".krige.bayes.extnd: anisotropy parameters provided and assumed to be constants\n")
       coords <- coords.aniso(coords = coords, aniso.pars = model$aniso.pars)
       if(do.prediction) locations <- coords.aniso(coords = locations, aniso.pars = model$aniso.pars)
       remove("dists.env")
@@ -299,8 +302,8 @@
                        kappa = model$kappa, nugget = tausq.rel.fixed,
                        cov.pars = c(1, phi.fixed), inv = TRUE,
                        only.inv.lower.diag = TRUE)
-  yiRy <- diagquadraticformXAX(data, iR$lower.inverse, iR$diag.inverse)
-  xiRy.x <- bilinearformXAY(X = trend.data, lowerA = iR$lower.inverse,
+  yiRy <- .diagquadraticformXAX(data, iR$lower.inverse, iR$diag.inverse)
+  xiRy.x <- .bilinearformXAY(X = trend.data, lowerA = iR$lower.inverse,
                             diagA = iR$diag.inverse, Y = cbind(data, trend.data))
   if(!is.matrix(xiRy.x)) xiRy.x <- is.matrix(xiRy.x, 1, n.datasets+beta.size)
   ind.datasets <- seq(length=n.datasets)
@@ -314,7 +317,7 @@
   }
   else{
     inv.beta.var.std.post <- as.matrix(beta.info$iv + xiRx)    
-    beta.var.std.post <- solve.geoR(inv.beta.var.std.post)
+    beta.var.std.post <- .solve.geoR(inv.beta.var.std.post)
     beta.post <- beta.var.std.post %*% (beta.info$ivm + xiRy.x[,ind.datasets])
   }
   ##
@@ -331,7 +334,7 @@
       S2.post <- sigmasq.info$n0S0 + yiRy - 2*crossprod(beta.post,xiRy.x[,ind.datasets,drop = FALSE]) + as.vector(t(beta.post)%*%xiRx%*%beta.post)
     }
     else{
-      S2.post <- sigmasq.info$n0S0 + beta.info$mivm + yiRy - diagquadraticformXAX(beta.post, inv.beta.var.std.post[lower.tri(inv.beta.var.std.post)], diag(inv.beta.var.std.post))     
+      S2.post <- sigmasq.info$n0S0 + beta.info$mivm + yiRy - .diagquadraticformXAX(beta.post, inv.beta.var.std.post[lower.tri(inv.beta.var.std.post)], diag(inv.beta.var.std.post))     
     }
     S2.post <- drop(S2.post/df.post)
   } 
@@ -356,7 +359,7 @@
                       cov.model = cov.model, kappa = kappa,
                       cov.pars = c(1, phi.fixed))
     ## care here, reusing object b
-    b <- bilinearformXAY(X = cbind(data, trend.data),
+    b <- .bilinearformXAY(X = cbind(data, trend.data),
                          lowerA = as.vector(iR$lower.inverse),
                          diagA = as.vector(iR$diag.inverse), 
                          Y = as.vector(v0))    
@@ -369,9 +372,9 @@
       kb$predictive$mean[loc.coincide,] <- data.coincide
     }
     ##
-    R.riRr.bVb <- 1 - diagquadraticformXAX(X = v0, lowerA = iR$lower.inverse, diagA = iR$diag.inverse)
+    R.riRr.bVb <- 1 - .diagquadraticformXAX(X = v0, lowerA = iR$lower.inverse, diagA = iR$diag.inverse)
     if(all(beta.info$iv != Inf))
-      R.riRr.bVb <- R.riRr.bVb + diagquadraticformXAX(X = t(b), lowerA=beta.var.std.post[lower.tri(beta.var.std.post)],
+      R.riRr.bVb <- R.riRr.bVb + .diagquadraticformXAX(X = t(b), lowerA=beta.var.std.post[lower.tri(beta.var.std.post)],
                                                       diagA = diag(beta.var.std.post))
     ##
     kb$predictive$variance <- as.vector(tausq.rel.fixed + R.riRr.bVb)%*%t(S2.post)
@@ -390,13 +393,13 @@
   if(do.prediction && simulations.predictive){
     if(is.R()){
       if(cov.model.number > 12)
-        stop("simulation in krige.bayes.extnd not implemented for the choice of correlation function")
+        stop("simulation in .krige.bayes.extnd not implemented for the choice of correlation function")
     }
     else
       if(cov.model.number > 10)
-        stop("simulation in krige.bayes.extnd not implemented for the chosen correlation function")
+        stop("simulation in .krige.bayes.extnd not implemented for the chosen correlation function")
     if(messages.screen){
-      cat("krige.bayes.extnd: sampling from the predictive\n")
+      cat(".krige.bayes.extnd: sampling from the predictive\n")
     }
     tmean <- kb$predictive$mean
     tv0ivdata <- NULL        ### se efter om den kan fjernes foer
@@ -416,7 +419,7 @@
     }
     kb$predictive$simulations <- matrix(NA, nrow=ni, ncol=n.datasets)
     if(nloc>0){
-      kb$predictive$simulations[ind.not.coincide,] <- cond.sim(env.loc = base.env, env.iter = base.env,
+      kb$predictive$simulations[ind.not.coincide,] <- .cond.sim(env.loc = base.env, env.iter = base.env,
                                                                loc.coincide = loc.coincide,
                                                                coincide.cond = coincide.cond, tmean = tmean,
                                                                Rinv = list(lower=iR$lower.inverse, diag=iR$diag.inverse),
@@ -437,7 +440,7 @@
 }
 
 
-"krige.conv.extnd" <- 
+".krige.conv.extnd" <- 
 function(geodata, coords = geodata$coords, data = geodata$data, locations, krige, output)
 {
 ##############################################################################
@@ -462,11 +465,11 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
   else{
     if(class(krige) != "krige.geoR"){
       if(!is.list(krige))
-        stop("krige.conv.extnd: the argument krige only takes a list or an output of the function krige.control")
+        stop(".krige.conv.extnd: the argument krige only takes a list or an output of the function krige.control")
       else{
         krige.names <-c("type.krige","trend.d","trend.l","obj.model","beta","cov.model",
 "cov.pars","kappa","nugget","micro.scale","dist.epsilon","lambda","aniso.pars")
-        krige <- object.match.names(krige,krige.names)
+        krige <- .object.match.names(krige,krige.names)
         if(is.null(krige$type.krige)) krige$type.krige <- "ok"  
         if(is.null(krige$trend.d)) krige$trend.d <-  "cte"
         if(is.null(krige$trend.l)) krige$trend.l <-  "cte"
@@ -507,11 +510,11 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
   else{
     if(class(output) != "output.geoR"){
       if(!is.list(output))
-        stop("krige.conv.extnd: the argument output only takes a list or an output of the function output.control")
+        stop(".krige.conv.extnd: the argument output only takes a list or an output of the function output.control")
       else{
         output.names <- c("n.posterior","n.predictive","moments","n.back.moments","simulations.predictive",
                           "mean.var","quantile","threshold","signal","messages.screen")
-        output <- object.match.names(output,output.names)
+        output <- .object.match.names(output,output.names)
         if(is.null(output$n.posterior)) output$n.posterior <- 1000 
         if(is.null(output$n.predictive)) output$n.predictive <- NULL
         if(is.null(output$moments)) output$moments <- TRUE
@@ -559,19 +562,19 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
     warning("vector of coordinates: one spatial dimension assumed")
   }
   coords <- as.matrix(coords)
-  locations <- check.locations(locations)
+  locations <- .check.locations(locations)
   dimnames(coords) <- list(NULL, NULL)
   dimnames(locations) <- list(NULL, NULL)
   ##
   if(messages.screen){
     if(is.numeric(krige$trend.d))
-      cat("krige.conv.extnd: model with covariates matrix provided by the user")
+      cat(".krige.conv.extnd: model with covariates matrix provided by the user")
     else
       cat(switch(as.character(krige$trend.d)[1],
-                 "cte" = "krige.conv.extnd: model with mean being constant",
-                 "1st" = "krige.conv.extnd: model with mean given by a 1st order polynomial on the coordinates",
-                 "2nd" = "krige.conv.extnd: model with mean given by a 2nd order polynomial on the coordinates",
-                 "krige.conv.extnd: model with mean defined by covariates provided by the user"))
+                 "cte" = ".krige.conv.extnd: model with mean being constant",
+                 "1st" = ".krige.conv.extnd: model with mean given by a 1st order polynomial on the coordinates",
+                 "2nd" = ".krige.conv.extnd: model with mean given by a 2nd order polynomial on the coordinates",
+                 ".krige.conv.extnd: model with mean defined by covariates provided by the user"))
     cat("\n")
   }
   trend.data <- unclass(trend.spatial(trend=krige$trend.d, geodata = geodata))
@@ -584,7 +587,7 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
   ## Anisotropy correction (should be placed AFTER trend.d/trend.l
   ##
   if(!is.null(krige$aniso.pars)){
-    if(messages.screen) cat("krige.conv.extnd: anisotropy correction performed\n")
+    if(messages.screen) cat(".krige.conv.extnd: anisotropy correction performed\n")
     coords <- coords.aniso(coords = coords, aniso.pars = krige$aniso.pars)
     locations <- coords.aniso(coords = locations, aniso.pars = krige$aniso.pars)
   }
@@ -592,7 +595,7 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
   ## Box-Cox transformation
   ##
   if(lambda != 1) {
-    if(messages.screen) cat("krige.conv.extnd: Data transformation (Box-Cox) performed.\n")
+    if(messages.screen) cat(".krige.conv.extnd: Data transformation (Box-Cox) performed.\n")
     if(lambda == 0)
       data <- log(data)
     else data <- ((data^lambda) - 1)/lambda
@@ -605,7 +608,7 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
     sigmasq <- cov.pars[1]
     phi <- cov.pars[2]
   }
-  else stop("covariance parametershould be given as a vector")
+  else stop("covariance parameter should be given as a vector")
   sill.partial <- krige$micro.scale + sigmasq
   sill.tot <- tausq + sigmasq
   ##
@@ -615,9 +618,9 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
   invcov <- varcov.spatial(coords = coords, cov.model = cov.model, kappa = kappa, nugget = nugget, cov.pars = cov.pars, 
                            inv = TRUE, only.inv.lower.diag = TRUE)
   ## From a numerical perspective there quite a few ugly bits here. See R-help e-mails from Bates and Ripley about LS/GLS. However, changing is not simple.
-  ittivtt <- solve.geoR(bilinearformXAY(trend.data, invcov$lower.inverse, invcov$diag.inverse, trend.data))
+  ittivtt <- .solve.geoR(.bilinearformXAY(trend.data, invcov$lower.inverse, invcov$diag.inverse, trend.data))
   if(beta.prior == "flat") {
-    beta.flat <- ittivtt %*% bilinearformXAY(trend.data, invcov$lower.inverse, invcov$diag.inverse, data)
+    beta.flat <- ittivtt %*% .bilinearformXAY(trend.data, invcov$lower.inverse, invcov$diag.inverse, data)
   }
   temp <- NULL
   d0mat <- loccoords(coords, locations)
@@ -628,33 +631,33 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
   else {
     v0 <- cov.spatial(obj = d0mat, cov.model = cov.model, kappa = kappa, cov.pars = cov.pars)
   }
-  tv0ivv0 <- diagquadraticformXAX(v0, invcov$lower.inverse, invcov$diag.inverse)
-  b <- trend.l - bilinearformXAY(v0, invcov$lower.inverse, invcov$diag.inverse, trend.data)
-  tv0ivdata <- bilinearformXAY(v0, invcov$lower.inverse, invcov$diag.inverse, data)
+  tv0ivv0 <- .diagquadraticformXAX(v0, invcov$lower.inverse, invcov$diag.inverse)
+  b <- t(trend.l - .bilinearformXAY(v0, invcov$lower.inverse, invcov$diag.inverse, trend.data))
+  tv0ivdata <- .bilinearformXAY(v0, invcov$lower.inverse, invcov$diag.inverse, data)
   if(n.predictive == 0) {
     remove(list = c("v0", "invcov"))
   }
   if(beta.prior == "deg") {
-    kc.result$predict <- array(tv0ivdata + rep(as.vector(b %*% beta), n.datasets), dim = c(ni, n.datasets))
+    kc.result$predict <- array(tv0ivdata + rep(drop(crossprod(b,beta)), n.datasets), dim = c(ni, n.datasets))
     if(n.predictive == 0) remove(list = c("b", "tv0ivdata"))
     else remove("tv0ivdata")
     if(output$signal) kc.result$krige.var <- as.vector(sill.partial - tv0ivv0)
     else kc.result$krige.var <- as.vector(sill.tot - tv0ivv0)
-    beta.est <- paste("krige.conv.extnd: Simple kriging (beta provided by user)\n")
+    beta.est <- paste(".krige.conv.extnd: Simple kriging (beta provided by user)\n")
   }
   if(beta.prior == "flat") {
-    kc.result$predict <- array(tv0ivdata, dim = c(ni, n.datasets)) + b %*% beta.flat
+    kc.result$predict <- array(tv0ivdata, dim = c(ni, n.datasets)) + crossprod(b,beta.flat)
     remove(list = c("tv0ivdata"))
-    if(beta.size == 1) bitb <- as.vector(b^2) * as.vector(ittivtt)
-    else bitb <- diagquadraticformXAX(t(b), ittivtt[lower.tri(ittivtt)], diag(ittivtt))
+    if(beta.size == 1) bitb <- drop(b^2) * drop(ittivtt)
+    else bitb <- .diagquadraticformXAX(b, ittivtt[lower.tri(ittivtt)], diag(ittivtt))
     if(output$signal) kc.result$krige.var <- as.vector(sill.partial - tv0ivv0 + bitb)
     else kc.result$krige.var <- as.vector(sill.tot - tv0ivv0 + bitb)
     kc.result$beta.est <- beta.flat
     remove("beta.flat")
   }
   if(any(round(kc.result$krige.var, dig=12) < 0))
-    warning("krige.conv.extnd: negative kriging variance found! Investigate why this is happening.\n")
-  out.message <- "krige.conv.extnd: Kriging performed using global neighbourhood"
+    warning(".krige.conv.extnd: negative kriging variance found! Investigate why this is happening.\n")
+  out.message <- ".krige.conv.extnd: Kriging performed using global neighbourhood"
   if(messages.screen) cat(paste(out.message, "\n"))
 ############## Sampling from the resulting distribution #####################
   if(n.predictive > 0) {
@@ -666,7 +669,7 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
     }
     else loc.coincide <- NULL
     d0mat <- NULL
-    if(messages.screen) cat("krige.conv.extnd: sampling from the predictive distribution (conditional simulations)\n")    
+    if(messages.screen) cat(".krige.conv.extnd: sampling from the predictive distribution (conditional simulations)\n")    
     if(signal) Dval <- 1. + (krige$micro.scale/sigmasq)
     else Dval <- 1. + (nugget/sigmasq)
     if(beta.prior == "deg") vbetai <- matrix(0, ncol = beta.size, nrow = beta.size)
@@ -681,14 +684,14 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
     else ind.not.coincide <- TRUE
     kc.result$simulations <- matrix(0, nrow = ni, ncol = n.datasets)
     if(nloc>0){
-      kc.result$simulations[ind.not.coincide,  ] <- cond.sim(env.loc = base.env, env.iter = base.env,  loc.coincide = loc.coincide,
+      kc.result$simulations[ind.not.coincide,  ] <- .cond.sim(env.loc = base.env, env.iter = base.env,  loc.coincide = loc.coincide,
                                                              coincide.cond = coincide.cond,
                                                              tmean = kc.result$predict[ind.not.coincide, , drop = FALSE],
                                                              Rinv = invcov,
                                                              mod = list(beta.size = beta.size, nloc = nloc,
                                                                Nsims = n.datasets, n = n, Dval = Dval,
                                                                df.model = NULL, s2 = sigmasq,
-                                                               cov.model.number = cor.number(cov.model),
+                                                               cov.model.number = .cor.number(cov.model),
                                                                phi = phi, kappa = kappa),
                                                              vbetai = vbetai, fixed.sigmasq = TRUE)
     }
@@ -700,24 +703,24 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
   if(lambda != 1) {
     if(lambda == 0){
       predict.transf <- kc.result$predict
-      if(messages.screen) cat("krige.conv.extnd: back-transforming the predictions using formula for EXP() \n")
+      if(messages.screen) cat(".krige.conv.extnd: back-transforming the predictions using formula for EXP() \n")
       kc.result$predict <- exp(predict.transf + 0.5 * kc.result$krige.var)
       kc.result$krige.var <- (exp(2 * predict.transf - kc.result$krige.var))*expm1(kc.result$krige.var)
       remove("predict.transf")
     }
     if(lambda > 0){
       ## using second order taylor-expansion + facts for N(0,1) [third moment = 0 ; fourth moment = 12].
-      if(messages.screen) cat("krige.conv.extnd: back-transforming predictions using 2. order Taylor expansion for g^{-1}() \n")
-      ivBC <- BC.inv(kc.result$predict,lambda)
+      if(messages.screen) cat(".krige.conv.extnd: back-transforming predictions using 2. order Taylor expansion for g^{-1}() \n")
+      ivBC <- .BC.inv(kc.result$predict,lambda)
       kc.result$predict <- ivBC + 0.5 * ((1-lambda)*ivBC^(1-2*lambda))*kc.result$krige.var
       kc.result$krige.var <- (ivBC^(1-lambda))^2*kc.result$krige.var + (11/4)*((1-lambda)*ivBC^(1-2*lambda))^2*kc.result$krige.var^2
       remove("ivBC")
     }
     if(lambda < 0){
-      if(messages.screen) cat("krige.conv.extnd: resulting distribution has no mean for lambda < 0 - back transformation not performed\n")
+      if(messages.screen) cat(".krige.conv.extnd: resulting distribution has no mean for lambda < 0 - back transformation not performed\n")
     }
     if(n.predictive > 0) {
-      kc.result$simulations <- BC.inv(kc.result$simulations,lambda)
+      kc.result$simulations <- .BC.inv(kc.result$simulations,lambda)
     }
   }
   else{
@@ -725,7 +728,7 @@ function(geodata, coords = geodata$coords, data = geodata$data, locations, krige
     kc.result$krige.var <- matrix(0, nrow = ni, ncol = n.datasets)
     kc.result$krige.var[] <- temp
   }
-  kc.result <- c(kc.result, list(message = message, call = cl))
+  kc.result <- c(kc.result, list(message = out.message, call = cl))
 #######################################
   return(kc.result)
 }
